==> dpws-model-1.1.0-sources.jar: org/somda/sdc/dpws/soap/model/Fault.java <==

package org.somda.sdc.dpws.soap.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * 
 * 	    Fault reporting structure
 * 	  
 * 
 * <p>Java class for Fault complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Fault"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="Code" type="{http://www.w3.org/2003/05/soap-envelope}faultcode"/&gt;
 *         &lt;element name="Reason" type="{http://www.w3.org/2003/05/soap-envelope}faultreason"/&gt;
 *         &lt;element name="Node" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/&gt;
 *         &lt;element name="Role" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/&gt;
 *         &lt;element name="Detail" type="{http://www.w3.org/2003/05/soap-envelope}detail" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Fault", namespace = "http://www.w3.org/2003/05/soap-envelope", propOrder = {
    "code",
    "reason",
    "node",
    "role",
    "detail"
})
public class Fault implements ToString2
{

    @XmlElement(name = "Code", namespace = "http://www.w3.org/2003/05/soap-envelope", required = true)
    protected Faultcode code;
    @XmlElement(name = "Reason", namespace = "http://www.w3.org/2003/05/soap-envelope", required = true)
    protected Faultreason reason;
    @XmlElement(name = "Node", namespace = "http://www.w3.org/2003/05/soap-envelope")
    @XmlSchemaType(name = "anyURI")
    protected String node;
    @XmlElement(name = "Role", namespace = "http://www.w3.org/2003/05/soap-envelope")
    @XmlSchemaType(name = "anyURI")
    protected String role;
    @XmlElement(name = "Detail", namespace = "http://www.w3.org/2003/05/soap-envelope")
    protected Detail detail;

    /**
     * Ruft den Wert der code-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Faultcode }
     *     
     */
    public Faultcode getCode() {
        return code;
    }

    /**
     * Legt den Wert der code-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Faultcode }
     *     
     */
    public void setCode(Faultcode value) {
        this.code = value;
    }

    /**
     * Ruft den Wert der reason-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Faultreason }
     *     
     */
    public Faultreason getReason() {
        return reason;
    }

    /**
     * Legt den Wert der reason-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Faultreason }
     *     
     */
    public void setReason(Faultreason value) {
        this.reason = value;
    }

    /**
     * Ruft den Wert der node-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNode() {
        return node;
    }

    /**
     * Legt den Wert der node-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNode(String value) {
        this.node = value;
    }

    /**
     * Ruft den Wert der role-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRole() {
        return role;
    }

    /**
     * Legt den Wert der role-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRole(String value) {
        this.role = value;
    }

    /**
     * Ruft den Wert der detail-Eigenschaft ab.
     * 
     * @return
     *     possible object is
     *     {@link Detail }
     *     
     */
    public Detail getDetail() {
        return detail;
    }

    /**
     * Legt den Wert der detail-Eigenschaft fest.
     * 
     * @param value
     *     allowed object is
     *     {@link Detail }
     *     
     */
    public void setDetail(Detail value) {
        this.detail = value;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final Fault that = ((Fault) object);
        {
            Faultcode leftCode;
            leftCode = this.getCode();
            Faultcode rightCode;
            rightCode = that.getCode();
            if (this.code!= null) {
                if (that.code!= null) {
                    if (!leftCode.equals(rightCode)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.code!= null) {
                    return false;
                }
            }
        }
        {
            Faultreason leftReason;
            leftReason = this.getReason();
            Faultreason rightReason;
            rightReason = that.getReason();
            if (this.reason!= null) {
                if (that.reason!= null) {
                    if (!leftReason.equals(rightReason)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.reason!= null) {
                    return false;
                }
            }
        }
        {
            String leftNode;
            leftNode = this.getNode();
            String rightNode;
            rightNode = that.getNode();
            if (this.node!= null) {
                if (that.node!= null) {
                    if (!leftNode.equals(rightNode)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.node!= null) {
                    return false;
                }
            }
        }
        {
            String leftRole;
            leftRole = this.getRole();
            String rightRole;
            rightRole = that.getRole();
            if (this.role!= null) {
                if (that.role!= null) {
                    if (!leftRole.equals(rightRole)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.role!= null) {
                    return false;
                }
            }
        }
        {
            Detail leftDetail;
            leftDetail = this.getDetail();
            Detail rightDetail;
            rightDetail = that.getDetail();
            if (this.detail!= null) {
                if (that.detail!= null) {
                    if (!leftDetail.equals(rightDetail)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.detail!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            Faultcode theCode;
            theCode = this.getCode();
            if (this.code!= null) {
                currentHashCode += theCode.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Faultreason theReason;
            theReason = this.getReason();
            if (this.reason!= null) {
                currentHashCode += theReason.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theNode;
            theNode = this.getNode();
            if (this.node!= null) {
                currentHashCode += theNode.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theRole;
            theRole = this.getRole();
            if (this.role!= null) {
                currentHashCode += theRole.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Detail theDetail;
            theDetail = this.getDetail();
            if (this.detail!= null) {
                currentHashCode += theDetail.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            Faultcode theCode;
            theCode = this.getCode();
            strategy.appendField(locator, this, "code", buffer, theCode, (this.code!= null));
        }
        {
            Faultreason theReason;
            theReason = this.getReason();
            strategy.appendField(locator, this, "reason", buffer, theReason, (this.reason!= null));
        }
        {
            String theNode;
            theNode = this.getNode();
            strategy.appendField(locator, this, "node", buffer, theNode, (this.node!= null));
        }
        {
            String theRole;
            theRole = this.getRole();
            strategy.appendField(locator, this, "role", buffer, theRole, (this.role!= null));
        }
        {
            Detail theDetail;
            theDetail = this.getDetail();
            strategy.appendField(locator, this, "detail", buffer, theDetail, (this.detail!= null));
        }
        return buffer;
    }

}

==> dpws-model-2.0.0-sources.jar: org/somda/sdc/dpws/soap/model/Fault.java <==

package org.somda.sdc.dpws.soap.model;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlSchemaType;
import javax.xml.bind.annotation.XmlType;
import org.jvnet.jaxb2_commons.lang.JAXBToStringStrategy;
import org.jvnet.jaxb2_commons.lang.ToString2;
import org.jvnet.jaxb2_commons.lang.ToStringStrategy2;
import org.jvnet.jaxb2_commons.locator.ObjectLocator;


/**
 * 
 * 	    Fault reporting structure
 * 	  
 * 
 * <p>Java class for Fault complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>
 * &lt;complexType name="Fault"&gt;
 *   &lt;complexContent&gt;
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType"&gt;
 *       &lt;sequence&gt;
 *         &lt;element name="Code" type="{http://www.w3.org/2003/05/soap-envelope}faultcode"/&gt;
 *         &lt;element name="Reason" type="{http://www.w3.org/2003/05/soap-envelope}faultreason"/&gt;
 *         &lt;element name="Node" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/&gt;
 *         &lt;element name="Role" type="{http://www.w3.org/2001/XMLSchema}anyURI" minOccurs="0"/&gt;
 *         &lt;element name="Detail" type="{http://www.w3.org/2003/05/soap-envelope}detail" minOccurs="0"/&gt;
 *       &lt;/sequence&gt;
 *     &lt;/restriction&gt;
 *   &lt;/complexContent&gt;
 * &lt;/complexType&gt;
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "Fault", namespace = "http://www.w3.org/2003/05/soap-envelope", propOrder = {
    "code",
    "reason",
    "node",
    "role",
    "detail"
})
public class Fault implements ToString2
{

    @XmlElement(name = "Code", namespace = "http://www.w3.org/2003/05/soap-envelope", required = true)
    protected Faultcode code;
    @XmlElement(name = "Reason", namespace = "http://www.w3.org/2003/05/soap-envelope", required = true)
    protected Faultreason reason;
    @XmlElement(name = "Node", namespace = "http://www.w3.org/2003/05/soap-envelope")
    @XmlSchemaType(name = "anyURI")
    protected String node;
    @XmlElement(name = "Role", namespace = "http://www.w3.org/2003/05/soap-envelope")
    @XmlSchemaType(name = "anyURI")
    protected String role;
    @XmlElement(name = "Detail", namespace = "http://www.w3.org/2003/05/soap-envelope")
    protected Detail detail;

    /**
     * Gets the value of the code property.
     * 
     * @return
     *     possible object is
     *     {@link Faultcode }
     *     
     */
    public Faultcode getCode() {
        return code;
    }

    /**
     * Sets the value of the code property.
     * 
     * @param value
     *     allowed object is
     *     {@link Faultcode }
     *     
     */
    public void setCode(Faultcode value) {
        this.code = value;
    }

    /**
     * Gets the value of the reason property.
     * 
     * @return
     *     possible object is
     *     {@link Faultreason }
     *     
     */
    public Faultreason getReason() {
        return reason;
    }

    /**
     * Sets the value of the reason property.
     * 
     * @param value
     *     allowed object is
     *     {@link Faultreason }
     *     
     */
    public void setReason(Faultreason value) {
        this.reason = value;
    }

    /**
     * Gets the value of the node property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getNode() {
        return node;
    }

    /**
     * Sets the value of the node property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setNode(String value) {
        this.node = value;
    }

    /**
     * Gets the value of the role property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getRole() {
        return role;
    }

    /**
     * Sets the value of the role property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setRole(String value) {
        this.role = value;
    }

    /**
     * Gets the value of the detail property.
     * 
     * @return
     *     possible object is
     *     {@link Detail }
     *     
     */
    public Detail getDetail() {
        return detail;
    }

    /**
     * Sets the value of the detail property.
     * 
     * @param value
     *     allowed object is
     *     {@link Detail }
     *     
     */
    public void setDetail(Detail value) {
        this.detail = value;
    }

    public boolean equals(Object object) {
        if ((object == null)||(this.getClass()!= object.getClass())) {
            return false;
        }
        if (this == object) {
            return true;
        }
        final Fault that = ((Fault) object);
        {
            Faultcode leftCode;
            leftCode = this.getCode();
            Faultcode rightCode;
            rightCode = that.getCode();
            if (this.code!= null) {
                if (that.code!= null) {
                    if (!leftCode.equals(rightCode)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.code!= null) {
                    return false;
                }
            }
        }
        {
            Faultreason leftReason;
            leftReason = this.getReason();
            Faultreason rightReason;
            rightReason = that.getReason();
            if (this.reason!= null) {
                if (that.reason!= null) {
                    if (!leftReason.equals(rightReason)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.reason!= null) {
                    return false;
                }
            }
        }
        {
            String leftNode;
            leftNode = this.getNode();
            String rightNode;
            rightNode = that.getNode();
            if (this.node!= null) {
                if (that.node!= null) {
                    if (!leftNode.equals(rightNode)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.node!= null) {
                    return false;
                }
            }
        }
        {
            String leftRole;
            leftRole = this.getRole();
            String rightRole;
            rightRole = that.getRole();
            if (this.role!= null) {
                if (that.role!= null) {
                    if (!leftRole.equals(rightRole)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.role!= null) {
                    return false;
                }
            }
        }
        {
            Detail leftDetail;
            leftDetail = this.getDetail();
            Detail rightDetail;
            rightDetail = that.getDetail();
            if (this.detail!= null) {
                if (that.detail!= null) {
                    if (!leftDetail.equals(rightDetail)) {
                        return false;
                    }
                } else {
                    return false;
                }
            } else {
                if (that.detail!= null) {
                    return false;
                }
            }
        }
        return true;
    }

    public int hashCode() {
        int currentHashCode = 1;
        {
            currentHashCode = (currentHashCode* 31);
            Faultcode theCode;
            theCode = this.getCode();
            if (this.code!= null) {
                currentHashCode += theCode.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Faultreason theReason;
            theReason = this.getReason();
            if (this.reason!= null) {
                currentHashCode += theReason.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theNode;
            theNode = this.getNode();
            if (this.node!= null) {
                currentHashCode += theNode.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            String theRole;
            theRole = this.getRole();
            if (this.role!= null) {
                currentHashCode += theRole.hashCode();
            }
        }
        {
            currentHashCode = (currentHashCode* 31);
            Detail theDetail;
            theDetail = this.getDetail();
            if (this.detail!= null) {
                currentHashCode += theDetail.hashCode();
            }
        }
        return currentHashCode;
    }

    public String toString() {
        final ToStringStrategy2 strategy = JAXBToStringStrategy.INSTANCE2;
        final StringBuilder buffer = new StringBuilder();
        append(null, buffer, strategy);
        return buffer.toString();
    }

    public StringBuilder append(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        strategy.appendStart(locator, this, buffer);
        appendFields(locator, buffer, strategy);
        strategy.appendEnd(locator, this, buffer);
        return buffer;
    }

    public StringBuilder appendFields(ObjectLocator locator, StringBuilder buffer, ToStringStrategy2 strategy) {
        {
            Faultcode theCode;
            theCode = this.getCode();
            strategy.appendField(locator, this, "code", buffer, theCode, (this.code!= null));
        }
        {
            Faultreason theReason;
            theReason = this.getReason();
            strategy.appendField(locator, this, "reason", buffer, theReason, (this.reason!= null));
        }
        {
            String theNode;
            theNode = this.getNode();
            strategy.appendField(locator, this, "node", buffer, theNode, (this.node!= null));
        }
        {
            String theRole;
            theRole = this.getRole();
            strategy.appendField(locator, this, "role", buffer, theRole, (this.role!= null));
        }
        {
            Detail theDetail;
            theDetail = this.getDetail();
            strategy.appendField(locator, this, "detail", buffer, theDetail, (this.detail!= null));
        }
        return buffer;
    }

}
